@@ -2,6 +2,9 @@
 .. include:: ../README.md
 
 """
+# both are set in style submodule to default value
+MODE = None
+STYLE = None
 
 from .colors import *
 from .plot import *
@@ -9,4 +12,4 @@ from .style import *
 from .texts import *
 from .subplots import *
 
-__version__ = '0.7.1'
+__version__ = '0.8.0'
