@@ -6,6 +6,8 @@ All rights reserved.
 
 """
 # ~~~ IMPORT ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+from collections import namedtuple
+
 import matplotlib as mpl
 import numpy as np
 from matplotlib import colors as clr
@@ -23,12 +25,26 @@ from prettypyplot.cmaps._discrete import (
     _pastel_rainbow,
     _pastel_spring,
     _paula,
+    _summertimes,
     _ufcd,
 )
 from prettypyplot.cmaps._macaw import _macaw
+from prettypyplot.cmaps._tol_discrete import (
+    _tol_bright,
+    _tol_high_contrast,
+    _tol_light,
+    _tol_medium_contrast,
+    _tol_muted,
+    _tol_vibrant,
+)
 from prettypyplot.cmaps._turbo import _turbo
 from prettypyplot.tools import is_number
 
+# ~~~ COLORS ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+GrayTones = namedtuple('GrayTones', 'dark light')
+black_grays = GrayTones('#000000', '#dddfe5')
+default_grays = GrayTones('#4d4f53', '#dddfe5')
+
 
 # ~~~ FUNCTIONS ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 def load_cmaps():
@@ -53,8 +69,15 @@ def load_cmaps():
         _pastel_autunm(),
         _pastel_rainbow(),
         _pastel_spring(),
-        _ufcd(),
         _paula(),
+        _summertimes(),
+        _tol_bright(),
+        _tol_high_contrast(),
+        _tol_light(),
+        _tol_medium_contrast(),
+        _tol_muted(),
+        _tol_vibrant(),
+        _ufcd(),
         _turbo(),
         _macaw(),
         _bownair(),
@@ -87,10 +110,10 @@ def load_colors():
         'pplt:green': _pastel5().colors[2],
         'pplt:orange': _pastel5().colors[3],
         'pplt:lightblue': _pastel5().colors[4],
-        'pplt:gray': default_grays['dark'],
-        'pplt:grey': default_grays['dark'],
-        'pplt:lightgray': default_grays['light'],
-        'pplt:lightgrey': default_grays['light'],
+        'pplt:gray': default_grays.dark,
+        'pplt:grey': default_grays.dark,
+        'pplt:lightgray': default_grays.light,
+        'pplt:lightgrey': default_grays.light,
         'pplt:axes': plt.rcParams['axes.edgecolor'],
         'pplt:text': plt.rcParams['text.color'],
         'pplt:grid': plt.rcParams['grid.color'],
@@ -299,9 +322,3 @@ def is_greyshade(color):
     if np.min(color) == np.max(color):
         return True
     return False
-
-
-# ~~~ COLORS ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-# gray tones
-black_grays = {'dark': '#000000', 'light': '#dddfe5'}
-default_grays = {'dark': '#4d4f53', 'light': '#dddfe5'}
