@@ -9,12 +9,14 @@ All rights reserved.
 import warnings
 from os import path
 
+import numpy as np
 from matplotlib import legend as mlegend
 from matplotlib import pyplot as plt
 from mpl_toolkits import axes_grid1 as mpl_axes_grid1
 
+import prettypyplot as _pplt
 from prettypyplot import tools
-from prettypyplot.style import __MODE, __STYLE
+from prettypyplot.style import Mode, Style
 
 
 # ~~~ FUNCTIONS ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -74,19 +76,8 @@ def plot(*args, ax=None, **kwargs):
     # plot
     lines = ax.plot(*args, **kwargs)
 
-    if __STYLE == 'minimal':
-        # TODO: change this to function
-        xminmax = _xminmax(ax)
-        xticks = ax.get_xticks()
-        if xticks.size:
-            ax.spines['bottom'].set_bounds(xminmax[0], xminmax[1])
-            ax.spines['top'].set_bounds(xminmax[0], xminmax[1])
-
-        yminmax = _yminmax(ax)
-        yticks = ax.get_yticks()
-        if yticks.size:
-            ax.spines['left'].set_bounds(yminmax[0], yminmax[1])
-            ax.spines['right'].set_bounds(yminmax[0], yminmax[1])
+    if _pplt.STYLE == Style.MINIMAL:
+        _set_spine_bounds(ax)
 
     return lines
 
@@ -115,10 +106,10 @@ def savefig(fname, use_canvas_size=True, **kwargs):
     # store figsize to reset it later
     set_figsize = figsize
 
-    if __STYLE == 'minimal':
+    if _pplt.STYLE == Style.MINIMAL:
         _reduce_ticks(fig)
 
-    if __MODE in {'poster', 'beamer'}:
+    if _pplt.MODE in {Mode.POSTER, Mode.BEAMER}:
         fig.set_size_inches(
             (3 * figsize[0], 3 * figsize[1]),
         )
@@ -147,6 +138,7 @@ def savefig(fname, use_canvas_size=True, **kwargs):
 
 def _reduce_ticks(fig):
     """Reduce number of ticks by factor 1.5 if more than 4."""
+    # TODO: replace this by mpl built-in class
     tick_reduc = 1.5
     for axes in fig.get_axes():
         if len(axes.get_xticks()) > 4:
@@ -163,6 +155,30 @@ def _reduce_ticks(fig):
             )
 
 
+def _legend_default_kwargs():
+    """Return default values of given outside positions."""
+    return {
+        'top': {
+            'bbox_to_anchor': (0.0, 1.0, 1.0, 0.01),
+            'mode': 'expand',
+            'loc': 'lower left',
+        },
+        'bottom': {
+            'bbox_to_anchor': (0.0, 0.0, 1.0, 0.01),
+            'mode': 'expand',
+            'loc': 'upper left',
+        },
+        'right': {
+            'bbox_to_anchor': (1.03, 0.5),
+            'loc': 'center left',
+        },
+        'left': {
+            'bbox_to_anchor': (-0.03, 0.5),
+            'loc': 'center right',
+        },
+    }
+
+
 def legend(*args, outside=False, ax=None, axs=None, **kwargs):
     """Generate a nice legend.
 
@@ -184,7 +200,8 @@ def legend(*args, outside=False, ax=None, axs=None, **kwargs):
         List of axes which are used for extracting all labels.
 
     ax : mpl.axes.Axes
-        Axes which is used for placing legend.
+        Axes which is used for placing legend. If none is specified `axs`
+        will be used if not `None` and otherwise the currently active axis
 
     args, kwargs
         See [pyplot.legend()](MPL_DOC.pyplot.legend.html)
@@ -199,26 +216,7 @@ def legend(*args, outside=False, ax=None, axs=None, **kwargs):
     .. include:: ../gallery/legend/README.md
 
     """
-    default_kwargs = {
-        'top': {
-            'bbox_to_anchor': (0.0, 1.0, 1.0, 0.01),
-            'mode': 'expand',
-            'loc': 'lower left',
-        },
-        'bottom': {
-            'bbox_to_anchor': (0.0, 0.0, 1.0, 0.01),
-            'mode': 'expand',
-            'loc': 'upper left',
-        },
-        'right': {
-            'bbox_to_anchor': (1.03, 0.5),
-            'loc': 'center left',
-        },
-        'left': {
-            'bbox_to_anchor': (-0.03, 0.5),
-            'loc': 'center right',
-        },
-    }
+    default_kwargs = _legend_default_kwargs()
     if outside not in {False, *default_kwargs}:
         raise ValueError(
             'Use for outside one of [False, {0}]'.format(
@@ -227,6 +225,20 @@ def legend(*args, outside=False, ax=None, axs=None, **kwargs):
         )
 
     # parse axes
+    if ax is not None:
+        ax = tools.gca(ax)
+        if axs is not None:
+            axs = tools.get_axes(axs)
+        else:
+            axs = [ax]
+    else:
+        if axs is not None:
+            axs = tools.get_axes(axs)
+            ax = tools.get_axes(axs)
+        else:
+            ax = plt.gca()
+            axs = [ax]
+
     args, ax = tools.parse_axes(*args, ax=ax)
 
     # parse axs
@@ -251,9 +263,9 @@ def legend(*args, outside=False, ax=None, axs=None, **kwargs):
 
     # generate legend
     leg = ax.legend(handles, labels, *args, **kwargs)
-    if __STYLE == 'minimal':
+    if _pplt.STYLE == Style.MINIMAL:
         leg.get_frame().set_linewidth(0.0)
-    elif __STYLE == 'default':
+    elif _pplt.STYLE == Style.DEFAULT:
         leg.get_frame().set_linewidth(plt.rcParams['axes.linewidth'])
 
     # shift title to the left if on top or bottom
@@ -381,7 +393,7 @@ def colorbar(im, width='7%', pad='0%', position='right', label=None, **kwargs):
     divider = mpl_axes_grid1.make_axes_locatable(ax)
     cax = divider.append_axes(position, width, pad=pad)
 
-    cbar = plt.colorbar(im, cax=cax, orientation=orientation)
+    cbar = plt.colorbar(im, cax=cax, orientation=orientation, **kwargs)
     if label:
         cbar.set_label(label)
 
@@ -416,7 +428,18 @@ def grid(*args, ax=None, **kwargs):
     # parse axes
     args, ax = tools.parse_axes(*args, ax=ax)
 
-    if __STYLE == 'default':
+    if 'b' not in kwargs:
+        boolargs = [arg for arg in args if isinstance(arg, bool)]
+        if len(boolargs) > 1:
+            raise ValueError('Only a single bool parameter is allowed.')
+        elif len(boolargs) == 1:
+            show_grid = boolargs[0]
+        else:
+            show_grid = True
+
+        kwargs['b'] = show_grid
+
+    if _pplt.STYLE == Style.DEFAULT:
         gr_maj = ax.grid(which='major', linestyle='--', **kwargs)
         gr_min = ax.grid(which='minor', linestyle='dotted', **kwargs)
         ax.set_axisbelow(True)
@@ -437,7 +460,18 @@ def _minmax(lim, rcparam):
     """Get range of plotted data."""
     width = lim[1] - lim[0]
     margin = plt.rcParams[rcparam]
-    return [  # min max
-        lim[0] + (margin + idx) / (1 + 2 * margin) * width
+    return lim[0] + np.array([  # min max
+        (margin + idx) / (1 + 2 * margin) * width
         for idx in (0, 1)
-    ]
+    ])
+
+
+def _set_spine_bounds(ax):
+    """Limit spines to data range, keeping ticks unchanged."""
+    for minmax, ticks, poss in (
+        (_xminmax(ax), ax.get_xticks(), ('bottom', 'top')),
+        (_yminmax(ax), ax.get_yticks(), ('left', 'right')),
+    ):
+        if ticks.size:
+            for pos in poss:
+                ax.spines[pos].set_bounds(*minmax)
