@@ -6,18 +6,56 @@ All rights reserved.
 
 """
 # ~~~ IMPORT ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+from enum import Enum, auto
 from os import path as ospath
 
 import numpy as np
 from matplotlib import pyplot as plt
+from decorit import copy_doc_params, deprecated
 
+import prettypyplot as _pplt
 from prettypyplot import tools
 from prettypyplot import colors as pclr
-from prettypyplot.decorators import copy_doc_params, deprecated
+
 
 # ~~~ CONSTANTS ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-__MODE = 'default'  # default mode
-__STYLE = 'default'  # default style
+class Style(Enum):
+    """Enum for all styles defined in pplt."""
+    DEFAULT = auto()
+    # default style, good for scientific usage
+    MINIMAL = auto()
+    # minimal style, good for slides, posters and co.
+    NONE = auto()
+    # do not change matplotlib style
+
+    @classmethod
+    def keys_list(cls):
+        """Return list of available Style names."""
+        return list(cls.__members__.keys())
+
+
+class Mode(Enum):
+    """Enum for all modes defined in pplt."""
+    DEFAULT = auto()
+    # default font size, good for monitor use
+    PRINT = auto()
+    # slightly larger fonts compared to default
+    BEAMER = auto()
+    # large fonts, good for slides
+    POSTER = auto()
+    # large fonts, good for A0 posters
+
+    @classmethod
+    def keys_list(cls):
+        """Return list of available Mode names."""
+        return list(cls.__members__.keys())
+
+
+# set default mode and style
+if _pplt.MODE is None:
+    _pplt.MODE = Mode.DEFAULT
+if _pplt.STYLE is None:
+    _pplt.STYLE = Style.DEFAULT
 
 
 # ~~~ FUNCTIONS ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -94,33 +132,55 @@ def update_style(
     """
     # set selected mode and style
     if mode is not None:
-        global __MODE
-        __MODE = mode
+        if isinstance(mode, Mode):
+            pass
+        elif isinstance(mode, str) and mode.upper() in Mode.keys_list():
+            mode = Mode[mode.upper()]
+        else:
+            assert ValueError(
+                'Mode "{mode}" is not supported, use one of {modes}.'.format(
+                    mode=mode,
+                    modes=Mode.keys_list(),
+                ),
+            )
+
+        _pplt.MODE = mode
+
     if style is not None:
-        global __STYLE
-        __STYLE = style
+        if isinstance(style, Style):
+            pass
+        elif isinstance(style, str) and style.upper() in Style.keys_list():
+            style = Style[style.upper()]
+        else:
+            assert ValueError(
+                'Style "{st}" is not supported, use one of {sts}.'.format(
+                    st=style,
+                    sts=Style.keys_list(),
+                ),
+            )
+        _pplt.STYLE = style
 
-    if style == 'none':
-        _reset_style()
-    else:
-        # load static rcParams
-        _apply_style('stylelib/default.mplstyle')
-        if style == 'minimal':
-            _apply_style('stylelib/minimal.mplstyle')
+        if _pplt.STYLE is Style.NONE:
+            _reset_style()
+        else:
+            # load static rcParams
+            _apply_style('stylelib/default.mplstyle')
+            if _pplt.STYLE is Style.MINIMAL:
+                _apply_style('stylelib/minimal.mplstyle')
 
-        # set color cycle and cmap
-        _set_rc_colors(
-            colors=colors, cmap=cmap, ncs=ncs, true_black=true_black,
-        )
+            # set color cycle and cmap
+            _set_rc_colors(
+                colors=colors, cmap=cmap, ncs=ncs, true_black=true_black,
+            )
 
-        # set figsize
-        _set_rc_figsize(figratio=figratio, figsize=figsize)
+            # set figsize
+            _set_rc_figsize(figratio=figratio, figsize=figsize)
 
-        # change widths and fontsize depending on MODE
-        _set_rc_widths(mode)
+            # change widths and fontsize depending on MODE
+            _set_rc_widths(mode)
 
-        # increase dpi if not in iypthon
-        _set_rc_dpi(ipython)
+            # increase dpi if not in iypthon
+            _set_rc_dpi(ipython)
 
     # set interactive mode
     _set_ineractive_mode(interactive=interactive)
@@ -142,8 +202,8 @@ def use_style(
     ncs=10,
     figsize=(3,),
     figratio='golden',
-    mode=__MODE,
-    style=__STYLE,
+    mode=_pplt.MODE,
+    style=_pplt.STYLE,
     ipython=False,
     true_black=False,
     latex=True,
@@ -193,8 +253,8 @@ def setup_pyplot(
     ncs=10,
     figsize=(3,),
     figratio='golden',
-    mode=__MODE,
-    style=__STYLE,
+    mode=_pplt.MODE,
+    style=_pplt.STYLE,
     ipython=False,
     true_black=False,
     latex=True,
@@ -237,7 +297,8 @@ def _set_rc_colors(colors, cmap, ncs, true_black):
             color_cycler = plt.cycler(color=plt.get_cmap(colors).colors)
         except AttributeError:
             color_cycler = plt.cycler(
-                color=plt.get_cmap(colors)(np.linspace(0, 1, ncs)))
+                color=plt.get_cmap(colors)(np.linspace(0, 1, ncs)),
+            )
 
         # TODO: refactor following code in private function
         plt.rcParams['axes.prop_cycle'] = color_cycler
@@ -248,20 +309,19 @@ def _set_rc_colors(colors, cmap, ncs, true_black):
     if true_black is not None:
         # change default colors
         if true_black:
-            gray_dark = pclr.black_grays['dark']
-            gray_light = pclr.black_grays['light']
+            grays = pclr.black_grays
         else:
-            gray_dark = pclr.default_grays['dark']
-            gray_light = pclr.default_grays['light']
+            grays = pclr.default_grays
 
-        plt.rcParams.update({'axes.edgecolor': gray_dark,
-                             'axes.labelcolor': gray_dark,
-                             'text.color': gray_dark,
-                             'patch.edgecolor': gray_dark,
-                             'xtick.color': gray_dark,
-                             'ytick.color': gray_dark,
-                             'patch.edgecolor': gray_dark,
-                             'grid.color': gray_light})
+        plt.rcParams.update({
+            'axes.edgecolor': grays.dark,
+            'axes.labelcolor': grays.dark,
+            'text.color': grays.dark,
+            'patch.edgecolor': grays.dark,
+            'xtick.color': grays.dark,
+            'ytick.color': grays.dark,
+            'grid.color': grays.light,
+        })
 
 
 def _set_rc_figsize(figratio, figsize):
@@ -281,24 +341,57 @@ def _set_rc_widths(mode):
     scales = _get_scale(mode)
     if scales is not None:
         for scale, rcParamsVal in [
-                ['small_scale', [['axes.linewidth', 0.8],
-                                 ['grid.linewidth', 0.8],
-                                 ['xtick.major.width', 0.8],
-                                 ['xtick.minor.width', 0.6]]],
-                ['tick_scale', [['xtick.major.size', 3.5],
-                                ['xtick.minor.size', 2.0],
-                                ['xtick.major.pad', 3.5],
-                                ['xtick.minor.pad', 3.4]]],
-                ['medium_scale', [['patch.linewidth', 1.0],
-                                  ['hatch.linewidth', 1.0]]],
-                ['large_scale', [['lines.linewidth', 1.5]]],
-                ['fontsize', [['font.size', 1]]]]:
+            [
+                'small_scale',
+                [
+                    ['axes.linewidth', 0.8],
+                    ['grid.linewidth', 0.8],
+                    ['xtick.major.width', 0.8],
+                    ['xtick.minor.width', 0.6],
+                ],
+            ],
+            [
+                'tick_scale',
+                [
+                    ['xtick.major.size', 3.5],
+                    ['xtick.minor.size', 2.0],
+                    ['xtick.major.pad', 3.5],
+                    ['xtick.minor.pad', 3.4],
+                ],
+            ],
+            [
+                'medium_scale',
+                [
+                    ['patch.linewidth', 1.0],
+                    ['hatch.linewidth', 1.0],
+                    ['boxplot.flierprops.markeredgewidth', 1.0],
+                    ['boxplot.flierprops.linewidth', 1.0],
+                    ['boxplot.boxprops.linewidth', 1.0],
+                    ['boxplot.whiskerprops.linewidth', 1.0],
+                    ['boxplot.capprops.linewidth', 1.0],
+                    ['boxplot.medianprops.linewidth', 1.0],
+                    ['boxplot.meanprops.linewidth', 1.0],
+                    ['lines.markeredgewidth', 1.0],
+                ],
+            ],
+            [
+                'large_scale',
+                [
+                    ['lines.linewidth', 1.5],
+                    ['boxplot.whiskers', 1.5],
+                    ['lines.markersize', 6],
+                ],
+            ],
+            ['fontsize', [['font.size', 1]]],
+        ]:
             scale = scales[scale]
             for rcParam, val in rcParamsVal:
                 plt.rcParams[rcParam] = scale * val
                 # apply all changes to yticks as well
                 if rcParam.startswith('xtick'):
-                    plt.rcParams['y' + rcParam[1:]] = plt.rcParams[rcParam]
+                    plt.rcParams[
+                        'y{0}'.format(rcParam[1:])
+                    ] = plt.rcParams[rcParam]
 
 
 def _set_rc_dpi(ipython, dpi=384):
@@ -325,39 +418,39 @@ def _set_ineractive_mode(interactive):
             plt.ioff()
 
 
-def _get_scale(mode):
+def _get_scale(mode: Mode):
     """Get the scaling factors."""
     scale_dict = {
-        'default': {
-            'large_scale': 1.,
-            'medium_scale': 1.,
-            'small_scale': 1.,
-            'tick_scale': 1.,
-            'fontsize': 10.,
+        Mode.DEFAULT: {
+            'large_scale': 1.0,
+            'medium_scale': 1.0,
+            'small_scale': 1.0,
+            'tick_scale': 1.0,
+            'fontsize': 10.0,
         },
-        'print': {
+        Mode.PRINT: {
             'large_scale': 1.5,
             'medium_scale': 1.7,
             'small_scale': 1.7,
             'tick_scale': 1.7,
-            'fontsize': 12.,
+            'fontsize': 12.0,
         },
-        'poster': {
-            'large_scale': 4.,
-            'medium_scale': 4.,
-            'small_scale': 4.,
-            'tick_scale': 4.,
-            'fontsize': 28.,
+        Mode.POSTER: {
+            'large_scale': 4.0,
+            'medium_scale': 4.0,
+            'small_scale': 4.0,
+            'tick_scale': 4.0,
+            'fontsize': 28.0,
+        },
+        Mode.BEAMER: {
+            'large_scale': 4.0,
+            'medium_scale': 4.0,
+            'small_scale': 4.0,
+            'tick_scale': 4.0,
+            'fontsize': 28.0,
         },
-        'beamer': {
-            'large_scale': 4.,
-            'medium_scale': 4.,
-            'small_scale': 4.,
-            'tick_scale': 4.,
-            'fontsize': 28.
-        }
     }
-    return scale_dict.get(mode, scale_dict['default'])
+    return scale_dict.get(mode, scale_dict[Mode.DEFAULT])
 
 
 def _reset_style():
